@@ -44,6 +44,8 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	if (!edit)
 		connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged(int)));
 
+	forceClose = false;
+
 	isNew = istemplate > 0 || _target == NULL;
 	typeChanged = false;
 
@@ -58,7 +60,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	if (istemplate > 0) {
 		this->target = new Target ();
 		if (istemplate > 1) {
-			this->target->name = "Copy of ";
+			this->target->name = tr("Copy of ");
 			this->target->name.append (_target->name);
 		}
 		this->target->type = _target->type;
@@ -105,26 +107,26 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 
 	if (edit) {
-		menuBar()->addAction("Save", this, SLOT(saveTarget()));
+		menuBar()->addAction(tr("Save"), this, SLOT(saveTarget()));
 		if (!isNew)
-			menuBar()->addAction("Delete", this, SLOT(_deleteTarget()));
-		menuBar()->addAction("Change Face Pict.", this, SLOT(cardFace()));
-		menuBar()->addAction("Mirror Face Pict.", this, SLOT(mirrorFace()));
-		menuBar()->addAction("Change Back Pict.", this, SLOT(cardBack()));
-		menuBar()->addAction("Mirror Back Pict.", this, SLOT(mirrorBack()));
-		menuBar()->addAction("Delete Face Pict.", this, SLOT(deleteCardFace()));
-		menuBar()->addAction("Delete Back Pict.", this, SLOT(deleteCardBack()));
-		menuBar()->addAction("Modify fields", this, SLOT(modifyFields()));
+			menuBar()->addAction(tr("Delete"), this, SLOT(_deleteTarget()));
+		menuBar()->addAction(tr("Change Face Pict."), this, SLOT(cardFace()));
+		menuBar()->addAction(tr("Mirror Face Pict."), this, SLOT(mirrorFace()));
+		menuBar()->addAction(tr("Change Back Pict."), this, SLOT(cardBack()));
+		menuBar()->addAction(tr("Mirror Back Pict."), this, SLOT(mirrorBack()));
+		menuBar()->addAction(tr("Delete Face Pict."), this, SLOT(deleteCardFace()));
+		menuBar()->addAction(tr("Delete Back Pict."), this, SLOT(deleteCardBack()));
+		menuBar()->addAction(tr("Modify fields"), this, SLOT(modifyFields()));
 		//TODO menuBar()->addAction("Delete field", this, SLOT(addNewField()));
 		//TODO menuBar()->addAction("Modify field", this, SLOT(addNewField()));
 	}
 	else {
-		menuBar()->addAction("New", this, SLOT(_newTarget()));
-		menuBar()->addAction("Edit", this, SLOT(_editTarget()));
-		menuBar()->addAction("New like this", this, SLOT(_newLikeTarget()));
-		menuBar()->addAction("Duplicate", this, SLOT(_duplicateTarget()));
-		menuBar()->addAction("Export Face Pict.", this, SLOT(exportCardFace()));
-		menuBar()->addAction("Export Back Pict.", this, SLOT(exportCardBack()));
+		menuBar()->addAction(tr("New Card"), this, SLOT(_newTarget()));
+		menuBar()->addAction(tr("Edit Card"), this, SLOT(_editTarget()));
+		menuBar()->addAction(tr("New Card like this"), this, SLOT(_newLikeTarget()));
+		menuBar()->addAction(tr("Duplicate Card"), this, SLOT(_duplicateTarget()));
+		menuBar()->addAction(tr("Export Face Pict."), this, SLOT(exportCardFace()));
+		menuBar()->addAction(tr("Export Back Pict."), this, SLOT(exportCardBack()));
 	}
 	
 	centralWidget = new QWidget(this);
@@ -151,18 +153,20 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	componentLayout = new QGridLayout ();
 	// Name label
 	if (edit) {
-		QLabel * nameLabel = new QLabel("Name", this);
+		QLabel * nameLabel = new QLabel(tr("Name"), this);
 		componentLayout->addWidget(nameLabel, 1, 1, 1, 2);
 
 	    nameLineEdit = new QLineEdit(this);
 		componentLayout->addWidget(nameLineEdit, 1, 3, 1, 4);
+		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 
 		nameLineEdit->setText (this->target->name);
 
-		nameLabel = new QLabel("Group Name", this);
+		nameLabel = new QLabel(tr("Group Name"), this);
 		componentLayout->addWidget(nameLabel, 2, 1, 1, 2);
 
 	    groupLineEdit = new QLineEdit(this);
+	    groupLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		componentLayout->addWidget(groupLineEdit, 2, 3, 1, 4);
 
 		groupLineEdit->setText (this->target->groupName);
@@ -172,8 +176,28 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 	}
 
 	if (edit) {
+		static const char *types_string[] = {
+		    QT_TR_NOOP("Membership Info"),
+		    QT_TR_NOOP("Password"),
+		    QT_TR_NOOP("Credit Card"),
+		    QT_TR_NOOP("Bank Account"),
+		    QT_TR_NOOP("Health Numbers"),
+		    QT_TR_NOOP("Passport Info"),
+		    QT_TR_NOOP("Note Card"),
+		    QT_TR_NOOP("Car Info"),
+		    QT_TR_NOOP("Cellular Phone"),
+		    QT_TR_NOOP("Serial Number Software"),
+		    QT_TR_NOOP("Serial Number Hardware"),
+		    QT_TR_NOOP("Web site"),
+		    QT_TR_NOOP("ID Card"),
+		    QT_TR_NOOP("Social Security Number"),
+		    QT_TR_NOOP("Email Account"),
+		    QT_TR_NOOP("Driver's License"),
+		    QT_TR_NOOP("Others")
+		};
+
 		// type label
-		QLabel * typeLabel = new QLabel("Type", this);
+		QLabel * typeLabel = new QLabel(tr("Type"), this);
 
 		componentLayout->addWidget(typeLabel, 3, 1, 1, 2);
 
@@ -181,7 +205,7 @@ DetailWindow::DetailWindow(Target * _target, const QString & groupName, int iste
 
 		bool selected = false;
 		for(int i = 0; i < this->parent->types->size(); i++) {
-			typeLineEdit->addItem (this->parent->types->at(i), this->parent->types->at(i));
+			typeLineEdit->addItem (tr(types_string[i])/*this->parent->types->at(i))*/, this->parent->types->at(i));
 
 			if (this->target->type == this->parent->types->at(i)) {
 				typeLineEdit->setCurrentIndex(i);
@@ -330,6 +354,7 @@ void DetailWindow::_addField (TargetField * field) {
 	//nameLabel->setContextMenuPolicy(Qt::NoContextMenu);
 	componentLayout->addWidget(nameLabel, pos + 1, 1, 1, 2);
 	nameLabel->setText (field->name);
+	nameLabel->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 	this->labels.append (nameLabel);
 
 	//ButtonInfo * info = new ButtonInfo (field);
@@ -339,7 +364,7 @@ void DetailWindow::_addField (TargetField * field) {
 		QTextEdit * nameLineEdit = new QTextEdit(this);
 		componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 4);
 		nameLineEdit->setText (field->value);
-		//nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
+		nameLineEdit->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
 		this->values.append (nameLineEdit);
 		//nameLineEdit->setUserData(0,info);
 	}
@@ -449,7 +474,7 @@ void DetailWindow::showFields () {
 					componentLayout->addWidget(nameLabel, pos + 1, 1, 1, 2);
 
 					if (field->type == TYPE_PASSWORD) {// || field->name.contains("password", Qt::CaseInsensitive)) {
-						QPushButton * nameLineEdit = new QPushButton("Click to see", this);
+						QPushButton * nameLineEdit = new QPushButton(tr("Click to see"), this);
 						//nameLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 						componentLayout->addWidget(nameLineEdit, pos + 1, 3, s, 2);
 
@@ -488,7 +513,7 @@ void DetailWindow::clickPass (QWidget * _wid) {
 	TargetField * f = ((ButtonInfo *)b->userData(0))->field;
 
 	if (b->text() == f->value) {
-		b->setText("Click to see");
+		b->setText(tr("Click to see"));
 	}
 	else {
 		b->setText(f->value);
@@ -541,7 +566,7 @@ void DetailWindow::saveTarget () {
 	if (nameLineEdit->text().length() < 1) {
 		if (messageBox.isNull()) {
 			messageBox = new QMessageBox(this);
-			messageBox->information(this, "Wallet", "Card description is missing", QMessageBox::Ok);
+			messageBox->information(this, "Wallet", tr("Card description is missing"), QMessageBox::Ok);
 		}
 		delete messageBox;
 		messageBox = 0;
@@ -551,7 +576,7 @@ void DetailWindow::saveTarget () {
 	 if (typeLineEdit->currentIndex() < 0) {
 		if (messageBox.isNull()) {
 			messageBox = new QMessageBox(this);
-			messageBox->information(this, "Wallet", "Type card is missing", QMessageBox::Ok);
+			messageBox->information(this, "Wallet", tr("Type card is missing"), QMessageBox::Ok);
 		}
 		delete messageBox;
 		messageBox = 0;
@@ -635,6 +660,7 @@ void DetailWindow::saveTarget () {
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 
+	forceClose = true;
 	close();
 }
 
@@ -647,30 +673,34 @@ void DetailWindow::_deleteTarget () {
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, false);
 
+	forceClose = true;
 	close();
 }
 
 void DetailWindow::_editTarget () {
 	emit editTarget(target);
 
+	forceClose = true;
 	close ();
 }
 
 void DetailWindow::_newLikeTarget () {
 	emit newLikeTarget(target);
 
+	forceClose = true;
 	close ();
 }
 void DetailWindow::_duplicateTarget () {
 	emit duplicateTarget(target);
 
+	forceClose = true;
 	close ();
 }
 
 void DetailWindow::_newTarget () {
-
 	emit newTarget();
 
+	forceClose = true;
 	close ();
 }
 
@@ -700,12 +730,12 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 	if (this->imageLabel != NULL && this->imageLabel->geometry().contains(p)) {
 		QMenu menu(this);
 		if (edit) {
-			menu.addAction("Edit", this, SLOT(cardFace()));
-			menu.addAction("Mirror", this, SLOT(mirrorFace()));
-			menu.addAction("Delete", this, SLOT(deleteCardFace()));
+			menu.addAction(tr("Edit"), this, SLOT(cardFace()));
+			menu.addAction(tr("Mirror"), this, SLOT(mirrorFace()));
+			menu.addAction(tr("Delete"), this, SLOT(deleteCardFace()));
 		}
 		else {
-			menu.addAction("Export Face", this, SLOT(exportCardFace()));
+			menu.addAction(tr("Export Face"), this, SLOT(exportCardFace()));
 		}
 		menu.exec(_p);
 	}
@@ -713,12 +743,12 @@ void DetailWindow::cardMenu(const QPoint & _p) {
 	if (this->imageBackLabel != NULL && this->imageBackLabel->geometry().contains(p)) {
 		QMenu menu(this);
 		if (edit) {
-			menu.addAction("Edit", this, SLOT(cardBack()));
-			menu.addAction("Mirror", this, SLOT(mirrorBack()));
-			menu.addAction("Delete", this, SLOT(deleteCardBack()));
+			menu.addAction(tr("Edit"), this, SLOT(cardBack()));
+			menu.addAction(tr("Mirror"), this, SLOT(mirrorBack()));
+			menu.addAction(tr("Delete"), this, SLOT(deleteCardBack()));
 		}
 		else {
-			menu.addAction("Export Back", this, SLOT(exportCardBack()));
+			menu.addAction(tr("Export Back"), this, SLOT(exportCardBack()));
 		}
 		menu.exec(_p);
 	}
@@ -736,9 +766,9 @@ void DetailWindow::exportCardFace()
 		QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
 		QString s = QFileDialog::getSaveFileName(
 	                this,
-	                "Choose card face image file",
+	                tr("Choose card face image file"),
 	                path,
-	                "Images (*.png)");
+	                tr("Images (*.png);;"));
 		if (!s.isNull () && !s.isEmpty ()) {
 			s.append(".png");
 			target->picture->save(s, "PNG"); // writes image into ba in PNG format
@@ -750,9 +780,9 @@ void DetailWindow::cardFace()
 	QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
 	QString s = QFileDialog::getOpenFileName(
 	                this,
-	                "Choose card face image",
+	                tr("Choose card face image"),
 	                path,
-	                "Images (*.png *.jpg *.gif *.jpeg)");
+	                tr("Images (*.png *.jpg *.gif *.jpeg);;"));
 
 	if (!s.isNull () && !s.isEmpty ()) {
 		//qDebug () << "loading " << s;
@@ -874,9 +904,9 @@ void DetailWindow::exportCardBack()
 		QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
 		QString s = QFileDialog::getSaveFileName(
 	                this,
-	                "Choose card back image file",
+	                tr("Choose card back image file"),
 	                path,
-	                "Images (*.png)");
+	                tr("Images (*.png);;"));
 		if (!s.isNull () && !s.isEmpty ()) {
 			s.append(".png");
 			target->pictureBack->save(s, "PNG"); // writes image into ba in PNG format
@@ -889,9 +919,9 @@ void DetailWindow::cardBack()
 	QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
 	QString s = QFileDialog::getOpenFileName(
 	                this,
-	                "Choose card back image",
+	                tr("Choose card back image"),
 	                path,
-	                "Images (*.png *.jpg *.gif *.jpeg)");
+	                tr("Images (*.png *.jpg *.gif *.jpeg);;"));
 	if (!s.isNull () && !s.isEmpty ()) {
 		//qDebug () << "loading " << s;
 		if (currentImageBackN) delete currentImageBackN;
@@ -907,7 +937,7 @@ void DetailWindow::cardBack()
 
 void DetailWindow::closeEvent(QCloseEvent *event) {
 	qDebug () << "close event";
-	if (edit || isNew) {
+	if ((!forceClose) && (edit || isNew)) {
 		bool isModified = false;
 
 		isModified |= typeChanged || nameLineEdit->isModified() || groupLineEdit->isModified();
@@ -929,7 +959,7 @@ void DetailWindow::closeEvent(QCloseEvent *event) {
 
 		if (isModified) {
 			QMessageBox * messageBox = new QMessageBox(this);
-			int b = messageBox->information(this, "Wallet", "Are you sure you want to discard changes?", QMessageBox::Yes, QMessageBox::No);
+			int b = messageBox->information(this, "Wallet", tr("Are you sure you want to discard changes?"), QMessageBox::Yes, QMessageBox::No);
 			if (b == QMessageBox::Yes) {
 				event->accept();
 			}
@@ -1012,7 +1042,7 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 	componentLayout->setSpacing(5);
 
 	// Name label
-	QLabel * nameLabel = new QLabel("Name", this);
+	QLabel * nameLabel = new QLabel(tr("Name"), this);
 	nameLabel->setContextMenuPolicy(Qt::NoContextMenu);
 	//nameLabel->setAlignment(Qt::AlignTop);
 	componentLayout->addWidget(nameLabel, 1, 1, 1, 2);
@@ -1025,7 +1055,7 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 	componentLayout->addWidget(nameLineEdit, 1, 3, 1, 4);
 
 	// type label
-	QLabel * typeLabel = new QLabel("Type", this);
+	QLabel * typeLabel = new QLabel(tr("Type"), this);
 	typeLabel->setContextMenuPolicy(Qt::NoContextMenu);
 	//typeLabel->setAlignment(Qt::AlignTop);
 	componentLayout->addWidget(typeLabel, 2, 1, 1, 2);
@@ -1035,18 +1065,18 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 	typeLineEdit->setContextMenuPolicy(Qt::NoContextMenu);
 	//typeLineEdit->setAlignment(Qt::AlignTop);
 
-	typeLineEdit->addItem ("String", QVariant(TYPE_STRING));
-	typeLineEdit->addItem ("Text", QVariant(TYPE_TEXT));
-	typeLineEdit->addItem ("Date", QVariant(TYPE_DATE));
-	typeLineEdit->addItem ("Number", QVariant(TYPE_INTEGER));
-	typeLineEdit->addItem ("Phone Number", QVariant(TYPE_PHONE_NUMBER));
-	typeLineEdit->addItem ("Password", QVariant(TYPE_PASSWORD));
-	typeLineEdit->addItem ("URL", QVariant(TYPE_URL));
+	typeLineEdit->addItem (tr("String"), QVariant(TYPE_STRING));
+	typeLineEdit->addItem (tr("Text"), QVariant(TYPE_TEXT));
+	typeLineEdit->addItem (tr("Date"), QVariant(TYPE_DATE));
+	typeLineEdit->addItem (tr("Number"), QVariant(TYPE_INTEGER));
+	typeLineEdit->addItem (tr("Phone Number"), QVariant(TYPE_PHONE_NUMBER));
+	typeLineEdit->addItem (tr("Password"), QVariant(TYPE_PASSWORD));
+	typeLineEdit->addItem (tr("URL"), QVariant(TYPE_URL));
 
 	componentLayout->addWidget(typeLineEdit, 2, 3, 1, 4);
 
 	// Name label
-	QLabel * orderLabel = new QLabel("Order", this);
+	QLabel * orderLabel = new QLabel(tr("Order"), this);
 	orderLabel->setContextMenuPolicy(Qt::NoContextMenu);
 	//nameLabel->setAlignment(Qt::AlignTop);
 	componentLayout->addWidget(orderLabel, 3, 1, 1, 2);
@@ -1054,6 +1084,7 @@ CreateFieldDialog::CreateFieldDialog(Target * target, DetailWindow *paTarget) :
 // Name line edit
 	orderEdit = new QLineEdit(this);
 	orderEdit->setContextMenuPolicy(Qt::NoContextMenu);
+	orderEdit->setInputMethodHints(Qt::ImhDigitsOnly);
 	orderEdit->setValidator(new QIntValidator (1, 100, this));
 
 	componentLayout->addWidget(orderEdit, 3, 3, 1, 4);
@@ -1090,6 +1121,7 @@ void CreateFieldDialog::addNew () {
 	update ();
 	pos = target->fields.length();
 	target->fields.append(new TargetField ("", TYPE_STRING, true, 100));
+
 	showField ();
 }
 void CreateFieldDialog::next () {
@@ -1109,8 +1141,31 @@ void CreateFieldDialog::deleteCurrent () {
 		}
 		showField ();
 	}
+	else {
+		nameLineEdit->hide ();
+		typeLineEdit->hide ();
+		orderEdit->hide ();
+	}
 }
 void CreateFieldDialog::showField () {
+	if (pos < target->fields.length()) {
+		if (!nameLineEdit->isEnabled()) {
+			nameLineEdit->setDisabled(false);
+			typeLineEdit->setDisabled(false);
+			orderEdit->setDisabled(false);
+		}
+	}
+	else {
+		if (nameLineEdit->isEnabled()) {
+			nameLineEdit->setText("");
+			orderEdit->setText("");
+
+			nameLineEdit->setDisabled(true);
+			typeLineEdit->setDisabled(true);
+			orderEdit->setDisabled(true);
+		}
+	}
+
 	if (pos == 0) {
 		previousButton->setDisabled(true);
 	}
