@@ -36,7 +36,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 		QString text ('0' + i + 1);
 
 		if (i == 9) {
-			text = "Ok";
+			text = tr("Ok");
 			imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_accept.png"),
 			//imageButton[i] ->setFixedSize(80, 80);
 			imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
@@ -64,7 +64,7 @@ LoginDialog::LoginDialog(bool firstTime, eWallet *paTarget): QWidget((QWidget*)p
 				QObject::connect(imageButton[i], SIGNAL(clicked()), signalMapper, SLOT(map()));
 			} else
 				if (i == 11) {
-					text = "Clear";
+					text = tr("Clear");
 					imageButton[i] = new QPushButton(text, this); // QIcon(":/resources/icon_clear.png"),
 					//imageButton[i] ->setFixedSize(80, 80);
 					imageButton[i] ->setContextMenuPolicy(Qt::NoContextMenu);
@@ -171,7 +171,7 @@ LoginDialog::~LoginDialog()
 }
 void LoginDialog::about()
 {
-    QMessageBox::about(this, "About Wallet", TEXT_ABOUT);
+    QMessageBox::about(this, tr("About Wallet"), tr(TEXT_ABOUT));
 }
 void LoginDialog::donate() {
 	QDesktopServices::openUrl( QUrl::fromEncoded("https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=nowheremanmail@gmail.com&lc=US&item_name=qtWallet&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted" ) );
@@ -189,7 +189,7 @@ void LoginDialog::acceptS() {
 	if (current.length() == 0) {
 		if (messageBox.isNull()) {
 			messageBox = new QMessageBox(this);
-			messageBox->information(this, "Wallet", "Password is required", QMessageBox::Ok);
+			messageBox->information(this, "Wallet", tr("Password is required"), QMessageBox::Ok);
 		}
 		delete messageBox;
 		messageBox = 0;
@@ -206,7 +206,7 @@ void LoginDialog::acceptS() {
 
 			if (messageBox.isNull()) {
 				messageBox = new QMessageBox(this);
-				messageBox->information(this, "Wallet", "For verification, please, enter your password again", QMessageBox::Ok);
+				messageBox->information(this, "Wallet", tr("For verification, please, enter your password again"), QMessageBox::Ok);
 			}
 			delete messageBox;
 			messageBox = 0;
@@ -219,7 +219,7 @@ void LoginDialog::acceptS() {
 				clearS ();
 				if (messageBox.isNull()) {
 					messageBox = new QMessageBox(this);
-					messageBox->information(this, "Wallet", "Invalid password, please enter again", QMessageBox::Ok);
+					messageBox->information(this, "Wallet", tr("Invalid password, please enter again"), QMessageBox::Ok);
 				}
 				delete messageBox;
 				messageBox = 0;
